@@ -1,4 +1,6 @@
 package Devel::ebug::Plugin::Codelines;
+use strict;
+use warnings;
 use base qw(Exporter);
 our @EXPORT = qw(codelines);
 
